package com.ibm.lab.soln.jdt.extras;

/*
 * "The Java Developer's Guide to Eclipse"
 *   by Shavor, D'Anjou, Fairbrother, Kehn, Kellerman, McCarthy
 * 
 * (C) Copyright International Business Machines Corporation, 2003. 
 * All Rights Reserved.
 * 
 * Code or samples provided herein are provided without warranty of any kind.
 */

import org.eclipse.jdt.core.Flags;
import org.eclipse.jdt.core.IMember;
import org.eclipse.jdt.core.JavaModelException;
import org.eclipse.jdt.core.compiler.ITerminalSymbols;
import org.eclipse.jface.action.IAction;


/**
 * Action to add/remove <code>final</code> modifier to/from <code>IMember</code>.
 */
public class ToggleIMemberFinalAction extends ChangeIMemberFlagAction {

	/**
	 * @see com.ibm.lab.soln.jdt.extras.ChangeIMemberFlagAction#performAction(IAction, IMember)
	 */
	protected boolean performAction(IAction action, IMember member) {
		boolean success = false;

		try {
//			if (action.isChecked())
			if (isChecked) {
				if ((member.getFlags() & Flags.AccFinal) == 0)
					success = insertFlag(member, Flags.AccFinal);
				else
					success =
						deleteFlag(
							member,
							Flags.AccFinal,
							ITerminalSymbols.TokenNamefinal);
			} else {
				if ((member.getFlags() & Flags.AccFinal) == 0)
					success = insertFlag(member, Flags.AccFinal);
			}
		} catch (JavaModelException e) {
		}

		return success;
	}

	/**
	 * @see com.ibm.lab.soln.jdt.extras.ChangeIMemberFlagAction#isChecked(IAction, IMember)
	 */
	protected boolean isChecked(IAction action, IMember member) {
		try {
			int flags = member.getFlags();
			return (flags & Flags.AccFinal) != 0;
		} catch (JavaModelException e) {
		}

		return false;
	}
}
